@@ -17,7 +17,7 @@ impl VideoMeta {
     #[doc(alias = "gst_buffer_add_video_meta")]
     pub fn add(
         buffer: &mut gst::BufferRef,
-        flags: crate::VideoFrameFlags,
+        video_frame_flags: crate::VideoFrameFlags,
         format: crate::VideoFormat,
         width: u32,
         height: u32,
@@ -45,7 +45,7 @@ impl VideoMeta {
         unsafe {
             let meta = ffi::gst_buffer_add_video_meta(
                 buffer.as_mut_ptr(),
-                flags.into_glib(),
+                video_frame_flags.into_glib(),
                 format.into_glib(),
                 width,
                 height,
@@ -61,7 +61,7 @@ impl VideoMeta {
 
     pub fn add_full<'a>(
         buffer: &'a mut gst::BufferRef,
-        flags: crate::VideoFrameFlags,
+        video_frame_flags: crate::VideoFrameFlags,
         format: crate::VideoFormat,
         width: u32,
         height: u32,
@@ -95,7 +95,7 @@ impl VideoMeta {
         unsafe {
             let meta = ffi::gst_buffer_add_video_meta_full(
                 buffer.as_mut_ptr(),
-                flags.into_glib(),
+                video_frame_flags.into_glib(),
                 format.into_glib(),
                 width,
                 height,
@@ -113,7 +113,7 @@ impl VideoMeta {
     }
 
     #[doc(alias = "get_flags")]
-    pub fn flags(&self) -> crate::VideoFrameFlags {
+    pub fn video_frame_flags(&self) -> crate::VideoFrameFlags {
         unsafe { from_glib(self.0.flags) }
     }
 
@@ -234,7 +234,7 @@ impl fmt::Debug for VideoMeta {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_struct("VideoMeta")
             .field("id", &self.id())
-            .field("flags", &self.flags())
+            .field("video_frame_flags", &self.video_frame_flags())
             .field("format", &self.format())
             .field("width", &self.width())
             .field("height", &self.height())
@@ -354,7 +354,7 @@ impl VideoRegionOfInterestMeta {
 
     #[doc(alias = "get_roi_type")]
     pub fn roi_type<'a>(&self) -> &'a str {
-        unsafe { glib::Quark::from_glib(self.0.roi_type).to_string() }
+        unsafe { glib::Quark::from_glib(self.0.roi_type).as_str() }
     }
 
     #[cfg(feature = "v1_14")]
@@ -461,7 +461,7 @@ impl VideoAffineTransformationMeta {
     #[doc(alias = "gst_buffer_add_meta")]
     pub fn add<'a>(
         buffer: &'a mut gst::BufferRef,
-        matrix: Option<&[f32; 16]>,
+        matrix: Option<&[[f32; 4]; 4]>,
     ) -> gst::MetaRefMut<'a, Self, gst::meta::Standalone> {
         skip_assert_initialized!();
         unsafe {
@@ -473,7 +473,9 @@ impl VideoAffineTransformationMeta {
 
             if let Some(matrix) = matrix {
                 let meta = &mut *meta;
-                meta.matrix.copy_from_slice(matrix);
+                for (i, o) in Iterator::zip(matrix.iter().flatten(), meta.matrix.iter_mut()) {
+                    *o = *i;
+                }
             }
 
             Self::from_mut_ptr(buffer, meta)
@@ -481,18 +483,23 @@ impl VideoAffineTransformationMeta {
     }
 
     #[doc(alias = "get_matrix")]
-    pub fn matrix(&self) -> &[f32; 16] {
-        &self.0.matrix
+    pub fn matrix(&self) -> &[[f32; 4]; 4] {
+        unsafe { &*(&self.0.matrix as *const [f32; 16] as *const [[f32; 4]; 4]) }
     }
 
-    pub fn set_matrix(&mut self, matrix: &[f32; 16]) {
-        self.0.matrix.copy_from_slice(matrix);
+    pub fn set_matrix(&mut self, matrix: &[[f32; 4]; 4]) {
+        for (i, o) in Iterator::zip(matrix.iter().flatten(), self.0.matrix.iter_mut()) {
+            *o = *i;
+        }
     }
 
     #[doc(alias = "gst_video_affine_transformation_meta_apply_matrix")]
-    pub fn apply_matrix(&mut self, matrix: &[f32; 16]) {
+    pub fn apply_matrix(&mut self, matrix: &[[f32; 4]; 4]) {
         unsafe {
-            ffi::gst_video_affine_transformation_meta_apply_matrix(&mut self.0, matrix);
+            ffi::gst_video_affine_transformation_meta_apply_matrix(
+                &mut self.0,
+                matrix as *const [[f32; 4]; 4] as *const [f32; 16],
+            );
         }
     }
 }
@@ -807,6 +814,68 @@ impl fmt::Debug for VideoBarMeta {
     }
 }
 
+#[cfg(any(feature = "v1_20", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+#[repr(transparent)]
+#[doc(alias = "GstVideoCodecAlphaMeta")]
+pub struct VideoCodecAlphaMeta(ffi::GstVideoCodecAlphaMeta);
+
+#[cfg(any(feature = "v1_20", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+unsafe impl Send for VideoCodecAlphaMeta {}
+#[cfg(any(feature = "v1_20", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+unsafe impl Sync for VideoCodecAlphaMeta {}
+
+#[cfg(any(feature = "v1_20", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+impl VideoCodecAlphaMeta {
+    #[doc(alias = "gst_buffer_add_video_codec_alpha_meta")]
+    pub fn add(
+        buffer: &mut gst::BufferRef,
+        alpha_buffer: gst::Buffer,
+    ) -> gst::MetaRefMut<Self, gst::meta::Standalone> {
+        skip_assert_initialized!();
+        unsafe {
+            let meta = ffi::gst_buffer_add_video_codec_alpha_meta(
+                buffer.as_mut_ptr(),
+                alpha_buffer.to_glib_none().0,
+            );
+
+            Self::from_mut_ptr(buffer, meta)
+        }
+    }
+
+    pub fn alpha_buffer(&self) -> &gst::BufferRef {
+        unsafe { gst::BufferRef::from_ptr(self.0.buffer) }
+    }
+
+    pub fn alpha_buffer_owned(&self) -> gst::Buffer {
+        unsafe { from_glib_none(self.0.buffer) }
+    }
+}
+
+#[cfg(any(feature = "v1_20", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+unsafe impl MetaAPI for VideoCodecAlphaMeta {
+    type GstType = ffi::GstVideoCodecAlphaMeta;
+
+    #[doc(alias = "gst_video_codec_alpha_meta_api_get_type")]
+    fn meta_api() -> glib::Type {
+        unsafe { from_glib(ffi::gst_video_codec_alpha_meta_api_get_type()) }
+    }
+}
+
+#[cfg(any(feature = "v1_20", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_20")))]
+impl fmt::Debug for VideoCodecAlphaMeta {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        f.debug_struct("VideoCodecAlphaMeta")
+            .field("buffer", &self.alpha_buffer())
+            .finish()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -826,7 +895,7 @@ mod tests {
             )
             .unwrap();
             assert_eq!(meta.id(), 0);
-            assert_eq!(meta.flags(), crate::VideoFrameFlags::empty());
+            assert_eq!(meta.video_frame_flags(), crate::VideoFrameFlags::empty());
             assert_eq!(meta.format(), crate::VideoFormat::Argb);
             assert_eq!(meta.width(), 320);
             assert_eq!(meta.height(), 240);
@@ -838,7 +907,7 @@ mod tests {
         {
             let meta = buffer.meta::<VideoMeta>().unwrap();
             assert_eq!(meta.id(), 0);
-            assert_eq!(meta.flags(), crate::VideoFrameFlags::empty());
+            assert_eq!(meta.video_frame_flags(), crate::VideoFrameFlags::empty());
             assert_eq!(meta.format(), crate::VideoFormat::Argb);
             assert_eq!(meta.width(), 320);
             assert_eq!(meta.height(), 240);
@@ -865,7 +934,7 @@ mod tests {
             )
             .unwrap();
             assert_eq!(meta.id(), 0);
-            assert_eq!(meta.flags(), crate::VideoFrameFlags::empty());
+            assert_eq!(meta.video_frame_flags(), crate::VideoFrameFlags::empty());
             assert_eq!(meta.format(), crate::VideoFormat::Argb);
             assert_eq!(meta.width(), 320);
             assert_eq!(meta.height(), 240);
@@ -877,7 +946,7 @@ mod tests {
         {
             let meta = buffer.meta::<VideoMeta>().unwrap();
             assert_eq!(meta.id(), 0);
-            assert_eq!(meta.flags(), crate::VideoFrameFlags::empty());
+            assert_eq!(meta.video_frame_flags(), crate::VideoFrameFlags::empty());
             assert_eq!(meta.format(), crate::VideoFormat::Argb);
             assert_eq!(meta.width(), 320);
             assert_eq!(meta.height(), 240);
