@@ -1,7 +1,9 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 use glib::translate::IntoGlib;
+use std::mem;
 
+#[repr(C)]
 #[derive(Clone, Debug, Eq, PartialEq, Hash)]
 pub struct VideoRectangle {
     pub x: i32,
@@ -46,3 +48,21 @@ pub fn center_video_rectangle(
     }
     VideoRectangle::new(result.x, result.y, result.w, result.h)
 }
+
+#[doc(hidden)]
+impl glib::translate::Uninitialized for VideoRectangle {
+    unsafe fn uninitialized() -> Self {
+        mem::zeroed()
+    }
+}
+
+#[doc(hidden)]
+impl<'a> glib::translate::ToGlibPtrMut<'a, *mut ffi::GstVideoRectangle> for VideoRectangle {
+    type Storage = &'a mut Self;
+
+    fn to_glib_none_mut(
+        &'a mut self,
+    ) -> glib::translate::StashMut<*mut ffi::GstVideoRectangle, Self> {
+        glib::translate::StashMut(self as *mut _ as *mut _, self)
+    }
+}
